@@ -1,24 +1,23 @@
 #pragma once
 
-#include <cstddef>
+#include "Stage.h"
 #include <cassert>
+#include <cstddef>
 #include <memory>
 #include <rumur/rumur.h>
-#include "Stage.h"
 #include <vector>
 
 class Pipeline {
 
- private:
-  std::vector<Stage*> stages;
+private:
+  std::vector<Stage *> stages;
 
   std::vector<std::shared_ptr<Stage>> managed;
 
- public:
+public:
   void add_stage(Stage &s);
 
-  template<typename T>
-  void make_stage() {
+  template <typename T> void make_stage() {
     assert(!stages.empty() && "make_stage() on an empty pipeline");
 
     auto s = std::make_shared<T>(*stages[0]);
