@@ -2,5 +2,13 @@
 
 #include <cstddef>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 extern const unsigned char doc_murphi2uclid_1[];
 extern const size_t doc_murphi2uclid_1_len;
+
+#ifdef __cplusplus
+}
+#endif
