@@ -33,12 +33,17 @@ private:
   void define_backing_mem(size_t id, const TypeExpr *t) {
     if (t != nullptr && !t->is_simple())
       *out << "  uint8_t ret" << id << "[BITS_TO_BYTES(" << t->width()
-           << ")];\n";
+           << ")] = {0};\n";
   }
 };
 
 } // namespace
 
+void generate_allocations(std::ostream &out, const Expr &expr) {
+  Generator g(out);
+  g.dispatch(expr);
+}
+
 void generate_allocations(std::ostream &out, const Stmt &stmt) {
   Generator g(out);
   g.dispatch(stmt);
