@@ -1,5 +1,5 @@
 -- checker_exit_code: 1
--- checker_output: None if self.xml else re.compile(r'^.*invariant "hello world" failed', re.MULTILINE)
+-- checker_output: None if xml else re.compile(r'^.*invariant "hello world" failed', re.MULTILINE)
 
 /* Test that the checker reports the name of an invariant in its failure
  * message.
