@@ -1,6 +1,6 @@
 -- checker_exit_code: 1
 -- rumur_flags: ['--scalarset-schedules', 'off']
--- checker_output: None if self.xml or getattr(self, 'multithreaded', False) else re.compile(r'^((?!t_)(.|\n))*$')
+-- checker_output: None if xml or multithreaded else re.compile(r'^((?!t_)(.|\n))*$')
 
 -- A variant of scalarset-schedules-off.m that checks startstate parameters are
 -- also not printed symbolically.
